#!/bin/bash
# This is the go.d.plugin->netdata version sync script.
# It ingests the updated go.d.plugin version information to netdata repository
#
# Execution Requirements:
#   - hub command
#   - GITHUB_TOKEN variable set with GitHub token
#
# Copyright: SPDX-License-Identifier: GPL-3.0-or-later
#
# Author: Pawel Krupa (@paulfantom)
# Author: Pavlos Emm. Katsoulakis (paul@netdata.cloud)

set -e

if [ ! -f .gitignore ]; then
	echo "Run as ./travis/$(basename "$0") from top level directory of git repository"
	exit 1
fi

if [ -z ${TRAVIS_TAG+x} ]; then
    exit 1
fi

CHECKSUM_FILE="$(pwd)/bin/sha256sums.txt"
NETDATA_GIT_URL="https://github.com/netdata/netdata.git"
LOCAL_NETDATA_DIR="netdata"
PR_TITLE="Use go.d.plugin in version ${TRAVIS_TAG}"
PR_MSG="This is an autogenerated pull request and it should consist of 17 line changes. Please review before merging."
export GIT_MAIL="bot@netdata.cloud"
export GIT_USER="netdatabot"

echo "--- Initialize git configuration ---"
git config user.email "${GIT_MAIL}"
git config user.name "${GIT_USER}"

echo "--- Cloning ${NETDATA_GIT_URL} --- "
git clone "${NETDATA_GIT_URL}" "${LOCAL_NETDATA_DIR}"
cd "${LOCAL_NETDATA_DIR}"

echo "--- Preparing changes for ${NETDATA_GIT_URL} ---"
cp "$CHECKSUM_FILE" packaging/go.d.checksums
echo "${TRAVIS_TAG}" > packaging/go.d.version
git checkout -b new_go_d_version
git add packaging/go.d.version packaging/go.d.checksums
git commit -m "installer: include go.d.plugin version ${TRAVIS_TAG}"

echo "--- Pushing changes to ${NETDATA_GIT_URL} --- "
hub pull-request -p -r paulkatsoulakis,ilyam8 -m "${PR_TITLE}" -m "${PR_MSG}"

echo "Netdata syncing completed successfully!"
